pub struct CollisionInfo<V> {
pub self_contact: V,
pub other_contact: V,
pub vector: V,
}Expand description
Information about a detected collision between collider objects. The data is stored in the specified vector type.
Fields
self_contact: VContact point on the first collider.
other_contact: VContact point on the other collider.
vector: VSmallest displacement vector to move the first collider so objects no longer touch.